/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.fieldplan;

import java.io.IOException;
import javax.swing.Action;
import nl.cloudfarming.client.fieldplan.model.FieldPlan;
import nl.cloudfarming.client.fieldplan.model.FieldPlanManager;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.util.lookup.ProxyLookup;
import org.openide.windows.TopComponent;

public class FieldPlanDataObject extends MultiDataObject {

    public static final String MIME_TYPE = "application/x-agrosense-fieldplan";
    public static final String ICON_BASE = "nl/cloudfarming/client/farm/fieldplan/Plant.png";
    public static final String EXT = "fpn";

    private FieldPlan fieldPlan;
    
    public FieldPlanDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        FieldPlanManager manager = Lookup.getDefault().lookup(FieldPlanManager.class);
        fieldPlan = manager.load(pf);
        registerEditor(MIME_TYPE, true);
    }

    public FieldPlan getFieldPlan(){
        return fieldPlan;
    }
    
    @Override
    protected int associateLookup() {
        return 1;
    }

    @Override
    protected Node createNodeDelegate() {
        Node delegate = super.createNodeDelegate();
        return new FieldPlanDataObjectNode(delegate, getPrimaryFile().getName());

    }

    @MultiViewElement.Registration(displayName = "#LBL_FieldPlan_EDITOR",
    iconBase = ICON_BASE,
    mimeType = MIME_TYPE,
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "FieldPlan",
    position = 1000)
    @Messages("LBL_FieldPlan_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }
    
    /**
     * Root node for the FieldPlan
     */
    private final class FieldPlanDataObjectNode extends AbstractNode {

        final Node origional;

        public FieldPlanDataObjectNode(Node original, String name) {
//            super(Children.create(new PartFieldNodeFactory(fieldPlan.getPartFields()), true), new ProxyLookup(original.getLookup()));
            super(Children.create(new FieldPlanChildFactory(fieldPlan.getPartFields()), true), new ProxyLookup(original.getLookup()));
            this.origional = original;
            setIconBaseWithExtension(ICON_BASE);
            setDisplayName(name);
        }

        @Override
        public Action[] getActions(boolean context) {
            return origional.getActions(context);
        }
    }
}