/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.fieldplan;


import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import nl.cloudfarming.client.fieldplan.model.FieldPlan;
import nl.cloudfarming.client.fieldplan.model.FieldPlanManager;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle.Messages;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@Messages({"FieldPlan name prefix=Field plan-"})
@ServiceProvider(service=FieldPlanManager.class)
public class FieldPlanManagerImpl implements FieldPlanManager {

    
    public static final String FARM_FIELDPLANS_DIR = "fieldplans";
    /**
     * 
     * @param fieldPlan
     * @param fileObject 
     */
    @Override
    public void save(FieldPlan fieldPlan, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(fieldPlan);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
    
    /**
     * loads a fieldplan from a fileobject
     * 
     * @param fileObject
     * @return 
     */
    @Override
    public FieldPlan load(FileObject fileObject) {
        FieldPlan fieldPlan = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            fieldPlan = (FieldPlan) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return fieldPlan;
    }
    
    @Override
    public FileObject getFieldPlansDirectory(FileObject projectDir){
        FileObject fieldPlansDir = projectDir.getFileObject(FARM_FIELDPLANS_DIR);
        if (fieldPlansDir == null){
            try {
                fieldPlansDir = projectDir.createFolder(FARM_FIELDPLANS_DIR);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        return fieldPlansDir;
    }

}
