/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.fieldplan;

import java.awt.Image;
import java.util.ArrayList;
import java.util.List;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.loaders.DataObject;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.ImageUtilities;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class FieldPlansNode extends FilterNode {

    private final DataFolder fieldPlansFolder;

    public FieldPlansNode(DataFolder fieldPlansFolder) {
        super(fieldPlansFolder.getNodeDelegate(), new FieldPlanChildren(fieldPlansFolder.getNodeDelegate()));
        this.fieldPlansFolder = fieldPlansFolder;
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(FieldPlanDataObject.ICON_BASE);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    public static class FieldPlanChildren extends FilterNode.Children {

        public FieldPlanChildren(Node owner) {
            super(owner);
        }

        @Override
        protected Node[] createNodes(Node object) {
            List<Node> result = new ArrayList<>();
            for (Node node : super.createNodes(object)) {
                FileObject fpFolderObject = node.getLookup().lookup(FileObject.class);
                if (fpFolderObject != null) {
                    DataFolder fpFolder = DataFolder.findFolder(fpFolderObject);
                    DataObject fieldPlanObject = null;
                    for (DataObject dataObject : fpFolder.getChildren()) {
                        if (dataObject instanceof FieldPlanDataObject) {
                            fieldPlanObject = dataObject;
                        }
                    }
                    if (fieldPlanObject != null) {
                        result.add(fieldPlanObject.getNodeDelegate());
                    }
                }
            }
            return result.toArray(new Node[0]);
        }
    }
}
