/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm.fieldplan;

import java.awt.datatransfer.Transferable;
import java.io.IOException;
import nl.cloudfarming.client.field.model.PartField;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.NodeTransfer;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * A node for a PartField
 *
 * @author Gerben Feenstra
 */
public final class PartFieldNode extends AbstractNode {

    private static final String PARTFIELD_NODE_ICON = "nl/cloudfarming/client/farm/fieldplan/partfield.png";
    private static final String PARTFIELD_LAYER_NAME = "ASPartfield_layer";
   

    /**
     * Create a PartFieldNode and specify a layer for this node in the lookup
     *
     * @param isobusPartField the isoBusPartField this node has to represent.
     * @param displayName Name to display for this node
     */
    public PartFieldNode(PartField partField) {
        super(Children.LEAF, Lookups.fixed(new SimpleLayer(PARTFIELD_LAYER_NAME), new PartFieldGeographical(partField)));    
        String displayName = NbBundle.getMessage(PartFieldNode.class, "farm-fieldplan.project.fieldplan.node.name", partField.getId(), partField.getName());
        this.setDisplayName(displayName);
        this.setIconBaseWithExtension(PARTFIELD_NODE_ICON);
    }

    @Override
    public Transferable drag() throws IOException {
        return clipboardCopy();
    }

    @Override
    public Transferable clipboardCopy() throws IOException {
        return NodeTransfer.transferable(this, NodeTransfer.CLIPBOARD_COPY);
    }

//    @Override
//    public HelpCtx getHelpCtx() {
//        return null;//new HelpCtx("nl.cloudfarming.client.isobus.project.explorer");
//    }
}
