/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm.fieldplan.wizard;

import java.awt.Component;
import java.util.HashSet;
import java.util.Set;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import org.netbeans.validation.api.Problems;
import org.netbeans.validation.api.ui.ValidationListener;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;

/**
 * Panel just asking for basic info.
 */
public class FieldPlanDetailsWizardPanel extends ValidationListener implements WizardDescriptor.Panel {

    private WizardDescriptor wizardDescriptor;
    private FieldPlanDetailsWizardPanelVisual component;
    private boolean valid = true;

    public FieldPlanDetailsWizardPanel() {
    }

    @Override
    public Component getComponent() {
        if (component == null) {
            component = new FieldPlanDetailsWizardPanelVisual();
            component.setName(NbBundle.getMessage(FieldPlanDetailsWizardPanel.class, "LBL_DetailsProjectStep"));
            ((FieldPlanDetailsWizardPanelVisual) component).addValidationListener(this);
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        return new HelpCtx("nl.cloudfarming.client.farm.fieldplan.about");
    }

    /**
     * validate the Problems if there are any valid will be false
     *
     * @param prblms
     * @return always true
     */
    @Override
    protected boolean validate(Problems prblms) {
        if (prblms.hasFatal()) {
            setValid(false);
        } else {
            setValid(true);
        }
        fireChangeEvent();
        return true;
    }

    private void setValid(boolean valid) {
        this.valid = valid;
    }

    @Override
    public boolean isValid() {
        return valid;
    }
    private final Set<ChangeListener> listeners = new HashSet<>(1); // or can use ChangeSupport in NB 6.0

    @Override
    public final void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }

    @Override
    public final void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }

    protected final void fireChangeEvent() {
        Set<ChangeListener> ls;
        synchronized (listeners) {
            ls = new HashSet<>(listeners);
        }
        ChangeEvent ev = new ChangeEvent(this);
        for (ChangeListener l : ls) {
            l.stateChanged(ev);
        }
    }

    @Override
    public void readSettings(Object settings) {
        wizardDescriptor = (WizardDescriptor) settings;
        component.read(wizardDescriptor);
    }

    @Override
    public void storeSettings(Object settings) {
        WizardDescriptor d = (WizardDescriptor) settings;
        component.store(d);
    }

}
