/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm.fieldplan.wizard;

import java.awt.Dimension;
import java.util.Calendar;
import java.util.Locale;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.validation.api.builtin.Validators;
import org.netbeans.validation.api.ui.ValidationListener;
import org.netbeans.validation.api.ui.ValidationPanel;
import org.openide.WizardDescriptor;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

@NbBundle.Messages({"FieldPlanWizardPanelVisual.fieldPlanYearLabel.text=Administration",
    "FieldPlanWizardPanelVisual.fieldPlanNameLabel.text=Name",
    "FieldPlanWizardPanelVisual.project_name=Field plan"})
public class FieldPlanDetailsWizardPanelVisual extends ASBodyPanel implements DocumentListener {

    private ImageIcon titleIcon = new ImageIcon(ImageUtilities.loadImage("nl/cloudfarming/client/farm/fieldplan/Plant32.png"));
    public static final String PROP_FIELD_PLAN_YEAR = "projectYear";
    public static final String PROP_FIELD_PLAN_NAME = "projectName";
    private static final String PROJECT_NAME = NbBundle.getMessage(FieldPlanDetailsWizardPanelVisual.class, "FieldPlanWizardPanelVisual.project_name");
    private static final String PROJECT_YEAR = new Integer(Calendar.getInstance().get(Calendar.YEAR)).toString();
    private static final int FIELD_WIDTH_PREFERRED = 400;
    
    private ValidationPanel validationPanel;
    private JLabel fieldPlanNameLabel;
    private JTextField fieldPlanNameTextField;
    private javax.swing.JLabel fieldPlanYearLabel;
    private javax.swing.JTextField fieldPlanYearTextfield;

    @SuppressWarnings("LeakingThisInConstructor")
    public FieldPlanDetailsWizardPanelVisual() {
        super(new MigLayout("wrap 2"));
        initComponents();
        // Register listener on the textFields to make the automatic updates
        fieldPlanYearTextfield.getDocument().addDocumentListener(this);
        fieldPlanNameTextField.getDocument().addDocumentListener(this);

    }

    public String getProjectName() {
        return this.fieldPlanYearTextfield.getText();
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    private void initComponents() {
        setIcon(titleIcon);
        fieldPlanNameLabel = new JLabel(NbBundle.getMessage(FieldPlanDetailsWizardPanelVisual.class, "FieldPlanWizardPanelVisual.fieldPlanNameLabel.text"));
        fieldPlanNameTextField = new JTextField();
        fieldPlanNameTextField.setPreferredSize(new Dimension(FIELD_WIDTH_PREFERRED, 0));
        
        fieldPlanYearLabel = new javax.swing.JLabel(NbBundle.getMessage(FieldPlanDetailsWizardPanelVisual.class, "FieldPlanWizardPanelVisual.fieldPlanYearLabel.text"));
        fieldPlanYearTextfield = new javax.swing.JTextField();
        fieldPlanYearTextfield.setPreferredSize(new Dimension(FIELD_WIDTH_PREFERRED, 0));
        validationPanel = new ValidationPanel();
        validationPanel.getValidationGroup().add(fieldPlanYearTextfield, Validators.validNumber(Locale.getDefault()));

        fieldPlanYearLabel.setLabelFor(fieldPlanYearTextfield);
        
        this.add(fieldPlanNameLabel);
        this.add(fieldPlanNameTextField);
        this.add(fieldPlanYearLabel);
        this.add(fieldPlanYearTextfield);
    }

    @Override
    public void addNotify() {
        super.addNotify();
        //same problem as in 31086, initial focus on Cancel button
        fieldPlanNameTextField.requestFocus();
    }

    boolean valid(WizardDescriptor wizardDescriptor) {
        return true;
    }

    /**
     * Adds a validationListener to this panels ValidationGroup
     *
     * @param validationListener
     */
    public void addValidationListener(ValidationListener validationListener) {
        validationPanel.getValidationGroup().add(validationListener);
    }

    void store(WizardDescriptor d) {
        String name = fieldPlanNameTextField.getText().trim();
        d.putProperty(PROP_FIELD_PLAN_NAME, name);
        String year = fieldPlanYearTextfield.getText().trim();
        d.putProperty(PROP_FIELD_PLAN_YEAR, year);
    }

    void read(WizardDescriptor settings) {
        String projectName = (String) settings.getProperty(PROP_FIELD_PLAN_NAME);
        String projectYear = (String) settings.getProperty(PROP_FIELD_PLAN_YEAR);
        if (projectName == null) {
            projectName = PROJECT_NAME;
        }
        if(projectYear == null){
            projectYear = PROJECT_YEAR;
        }
        this.fieldPlanNameTextField.setText(projectName);
        this.fieldPlanNameTextField.selectAll();
        this.fieldPlanYearTextfield.setText(projectYear); 
        setTitle();
    }
    
    private void setTitle(){
        this.setTitle(fieldPlanNameTextField.getText() + "-" + fieldPlanYearTextfield.getText());
    }
    

    // Implementation of DocumentListener --------------------------------------
    @Override
    public void changedUpdate(DocumentEvent e) {
        if (this.fieldPlanYearTextfield.getDocument() == e.getDocument() || this.fieldPlanNameTextField.getDocument() == e.getDocument()) {
            validationPanel.getValidationGroup().validateAll();
            setTitle();
            firePropertyChange(PROP_FIELD_PLAN_YEAR, null, this.fieldPlanYearTextfield.getText());
        }
    }

    @Override
    public void insertUpdate(DocumentEvent e) {
        if (this.fieldPlanYearTextfield.getDocument() == e.getDocument() || this.fieldPlanNameTextField.getDocument() == e.getDocument()) {
            validationPanel.getValidationGroup().validateAll();
            setTitle();
            firePropertyChange(PROP_FIELD_PLAN_YEAR, null, this.fieldPlanYearTextfield.getText());
        }
    }

    @Override
    public void removeUpdate(DocumentEvent e) {
        if (this.fieldPlanYearTextfield.getDocument() == e.getDocument() || this.fieldPlanNameTextField.getDocument() == e.getDocument()) {
            setTitle();
            validationPanel.getValidationGroup().validateAll();
            firePropertyChange(PROP_FIELD_PLAN_YEAR, null, this.fieldPlanYearTextfield.getText());
        }
    }
}
