/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm.fieldplan.wizard;

import java.awt.Component;
import java.util.List;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.field.model.Field;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;

/**
 * Controller for FieldPlanSummaryPanelVisual
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"fieldplan_summary_panel_title=Overview"})
public class FieldPlanSummaryPanel implements WizardDescriptor.Panel, WizardDescriptor.FinishablePanel {

    private FieldPlanSummaryPanelVisual panelVisual;
    private static final String TITLE = NbBundle.getMessage(FieldPlanSummaryPanel.class, "fieldplan_summary_panel_title");

    @Override
    public Component getComponent() {
        if (panelVisual == null) {
            panelVisual = new FieldPlanSummaryPanelVisual();
            panelVisual.setTitle(TITLE);
            panelVisual.setName(TITLE);
        }
        return panelVisual;
    }

    @Override
    public HelpCtx getHelp() {
        return new HelpCtx("nl.cloudfarming.client.farm.fieldplan.about");
    }

    @Override
    public void readSettings(Object settings) {
        WizardDescriptor wizardDescriptor = (WizardDescriptor) settings;
        FieldPlanSummaryPanelVisual visual = (FieldPlanSummaryPanelVisual) getComponent();
        String fieldPlanName= (String) wizardDescriptor.getProperty(FieldPlanDetailsWizardPanelVisual.PROP_FIELD_PLAN_NAME);
        String fieldPlanYear = (String) wizardDescriptor.getProperty(FieldPlanDetailsWizardPanelVisual.PROP_FIELD_PLAN_YEAR);
        
        List<Field> fields = (List<Field>) wizardDescriptor.getProperty(FieldPlanFieldsWizardPanelVisual.PROP_SELECTED_FIELDS);
        
        visual.setFieldPlanName(fieldPlanName);
        visual.setFieldPlanYear(fieldPlanYear);
        visual.setFields(fields);
        
    }

    @Override
    public void storeSettings(Object settings) {
        WizardDescriptor wizardDescriptor = (WizardDescriptor) settings;
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    @Override
    public boolean isFinishPanel() {
        return true;
    }
}
