/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm.fieldplan.wizard;

import java.awt.Color;
import java.awt.Dimension;
import java.util.List;
import javax.swing.*;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * Panel which summarizes all previous wizard steps
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"fieldPlanSummaryPanelVisual_fieldPlanNameLabel=Name:",
    "fieldPlanSummaryPanelVisual_fieldPlanYearLabel=Year:",
    "fieldPlanSummaryPanelVisual_fieldsLabel=Fields:",
    "fieldPlanSummaryPanelVisual_createProductionUnitLabel=Add crops to fieldplan after wizard finishes"})
public class FieldPlanSummaryPanelVisual extends ASBodyPanel {

    private ImageIcon titleIcon = new ImageIcon(ImageUtilities.loadImage("nl/cloudfarming/client/farm/fieldplan/Plant32.png"));
    private static final String NAME_LABEL_TEXT = NbBundle.getMessage(FieldPlanSummaryPanelVisual.class, "fieldPlanSummaryPanelVisual_fieldPlanNameLabel");
    private static final String YEAR_LABEL_TEXT = NbBundle.getMessage(FieldPlanSummaryPanelVisual.class, "fieldPlanSummaryPanelVisual_fieldPlanYearLabel");
    private static final String FIELDS_LABEL_TEXT = NbBundle.getMessage(FieldPlanSummaryPanelVisual.class, "fieldPlanSummaryPanelVisual_fieldsLabel");
    private static final String CREATE_PRODUCTION_UNIT_LABEL_TEXT = NbBundle.getMessage(FieldPlanSummaryPanelVisual.class, "fieldPlanSummaryPanelVisual_createProductionUnitLabel");
    private JLabel fieldPlanNameLabel;
    private JLabel fieldPlanYearLabel;
    private JLabel fieldsLabel;
    private JLabel fieldPlanNameTextField;
    private JLabel fieldPlanYearTextField;
    
    private JList fieldsList;
    private DefaultListModel<Field> fieldModel;
    private JScrollPane fieldScrolPane;
    private JCheckBox createProductionUnit;
    
    private static final int LIST_HEIGHT = 300;
    private static final int LIST_WIDHT = 150;

    public FieldPlanSummaryPanelVisual() {
        super(new MigLayout("wrap 2, insets 0 0 0 0"));
        init();
    }

    private void init() {
        setIcon(titleIcon);
        fieldPlanNameLabel = new JLabel(NAME_LABEL_TEXT);
        fieldPlanYearLabel = new JLabel(YEAR_LABEL_TEXT);
        fieldsLabel = new JLabel(FIELDS_LABEL_TEXT);
        
        
        fieldPlanNameTextField = new JLabel();
        fieldPlanYearTextField = new JLabel();

        fieldModel = new DefaultListModel<>();
        fieldsList = new JList(fieldModel);
        fieldsList.setEnabled(false);

        fieldScrolPane = new JScrollPane(fieldsList);
        fieldScrolPane.setPreferredSize(new Dimension(LIST_WIDHT, LIST_HEIGHT));

        createProductionUnit = new JCheckBox(CREATE_PRODUCTION_UNIT_LABEL_TEXT, true);
        createProductionUnit.setBackground(Color.white);
        
        this.add(fieldPlanNameLabel);
        this.add(fieldPlanNameTextField);
        this.add(fieldPlanYearLabel);
        this.add(fieldPlanYearTextField);
        this.add(fieldsLabel);
        this.add(fieldScrolPane);
        this.add(createProductionUnit, "span 2");
    }

    public void setFieldPlanName(String name) {
        fieldPlanNameTextField.setText(name);
    }

    public void setFieldPlanYear(String year) {
        fieldPlanYearTextField.setText(year);
    }

    public void setFields(List<Field> fields) {
        fieldModel.clear();
        for (Field field : fields) {
            fieldModel.addElement(field);
        }
    }
}
